@@ -1,12 +1,8 @@
-#pylint: disable=logging-fstring-interpolation
 #Standart library imports
-import shutil
 import time
 from pathlib import Path
+from packaging import version
 
-# Third party imports
-import wget
-import xmltodict
 
 # Local imports
 
@@ -70,7 +66,7 @@ class EdgeDriver(DriverBase):
         """
         driver_path : str = ''
 
-        if self.check_driver_is_up_to_date and not self.system_name:
+        if not self.system_name:
 
             is_driver_up_to_date, current_version, latest_version = super()._compare_current_version_and_latest_version()
 
@@ -79,7 +75,7 @@ class EdgeDriver(DriverBase):
 
         driver_path = self._download_driver()
 
-        if self.check_driver_is_up_to_date and not self.system_name:
+        if not self.system_name:
 
             is_driver_up_to_date, current_version, latest_version = super()._compare_current_version_and_latest_version()
 
@@ -110,17 +106,19 @@ class EdgeDriver(DriverBase):
 
         latest_version = super()._get_latest_version_driver()
 
-        latest_version_main = int(latest_version.split('.', maxsplit=1)[0])
+        latest_version_main = version.parse(latest_version).major
         latest_previous_version_main = str(latest_version_main-1)
 
-        url = self.setting["EdgeDriver"]["LinkLatestReleaseSpecificVersion"]
-        json_data = self.requests_getter.get_result_by_request(url=url)
-        data = xmltodict.parse(json_data)
-        versions = data.get('EnumerationResults').get('Blobs').get('Blob')
-        latest_previous_versions = [version for version in versions if version.get('Name').startswith(latest_previous_version_main)]
-        previous_versions_suitable = [version for version in latest_previous_versions if version.get('Name').split('/')[-1] == self.setting['EdgeDriver']['LinkLastReleaseFile'].split('/')[-1]]
+        if 'arm64' in self.setting["EdgeDriver"]["LinkLastReleaseFile"] or 'win' in  self.setting["EdgeDriver"]["LinkLastReleaseFile"]:
+            platform_url = 'WINDOWS'
+        elif 'mac64' in self.setting["EdgeDriver"]["LinkLastReleaseFile"]:
+            platform_url = 'MACOS'
+        else:
+            platform_url = 'LINUX'
 
-        latest_previous_version = previous_versions_suitable[-1].get('Name').split('/')[0]
+        url = self.setting["EdgeDriver"]["LinkLatestReleaseSpecificVersion"].format(latest_previous_version_main, platform_url)
+        json_data = self.requests_getter.get_result_by_request(url=url)
+        latest_previous_version = json_data.strip()
         logger.info(f'Latest previous version of edgedriver: {latest_previous_version}')
 
         return latest_previous_version
@@ -140,22 +138,14 @@ class EdgeDriver(DriverBase):
         """
 
         url : str = ''
-        driver_notes_path : str = self.path + 'Driver_Notes'
         latest_previous_version : str = ''
         latest_version : str = ''
 
         driver_path : str = ''
 
-        if self.upgrade:
+        super()._delete_current_driver_for_current_os()
 
-            super()._delete_current_driver_for_current_os()
-
-        if version:
-
-            url = str(self.setting["EdgeDriver"]["LinkLastReleaseFile"]).format(version)
-            logger.info(f'Started download edgedriver specific_version: {version}')
-
-        elif previous_version:
+        if previous_version:
 
             latest_previous_version = self._get_latest_previous_version_edgedriver_via_requests()
 
@@ -163,11 +153,15 @@ class EdgeDriver(DriverBase):
             logger.info(f'Started download edgedriver latest_previous_version: {latest_previous_version}')
 
         else:
+            
+            if self.version:
+                self.setting["EdgeDriver"]["LinkLastRelease"] = self.setting["EdgeDriver"]["LinkLastRelease"].replace('STABLE', self.version.split('_')[1].upper())
 
             latest_version = super()._get_latest_version_driver()
 
             url = str(self.setting["EdgeDriver"]["LinkLastReleaseFile"]).format(latest_version)
-            logger.info(f'Started download edgedriver latest_version: {latest_version}')
+            channel = '' if '_' not in self.version else self.version.split('_')[1]
+            logger.info(f'Started download edgedriver {channel} latest_version: {latest_version}')
 
         if self.system_name:
             url = url.replace(url.split("/")[-1], '')
@@ -179,7 +173,7 @@ class EdgeDriver(DriverBase):
             if 'mac64_m1' in url:
                 try:
                     super()._check_if_version_is_valid(url=url)
-                except:
+                except Exception:
                     logger.warning('Could not find binary with mac64_m1 name, trying to download standart mac binary')
                     url = url.replace('mac64_m1', 'mac64')
                     super()._check_if_version_is_valid(url=url)
@@ -193,11 +187,7 @@ class EdgeDriver(DriverBase):
             Path(out_path).unlink()
 
         logger.info(f'Started download edgedriver by url: {url}')
-
-        if self.info_messages:
-            archive_path = wget.download(url=url, out=out_path)
-        else:
-            archive_path = wget.download(url=url, out=out_path, bar=None)
+        archive_path = super()._wget_download_driver(url, out_path)
         time.sleep(2)
 
         logger.info(f'Edgedriver was downloaded to path: {archive_path}')
@@ -221,16 +211,11 @@ class EdgeDriver(DriverBase):
         if Path(archive_path).exists():
             Path(archive_path).unlink()
 
-        if Path(driver_notes_path).exists():
-            shutil.rmtree(driver_notes_path)
-
         driver_path = self.edgedriver_path
 
         logger.info(f'Edgedriver was successfully unpacked by path: {driver_path}')
 
-        if self.chmod:
-
-            super()._chmod_driver()
+        super()._chmod_driver()
 
         return driver_path
         
\ No newline at end of file
