@@ -1,12 +1,8 @@
-#pylint: disable=logging-fstring-interpolation
 #Standart library imports
 import time
 import re
 from pathlib import Path
 
-# Third party imports
-import wget
-
 # Local imports
 
 from selenium_driver_updater.util.logger import logger
@@ -79,7 +75,7 @@ class GeckoDriver(DriverBase):
         """
         driver_path : str = ''
 
-        if self.check_driver_is_up_to_date and not self.system_name:
+        if not self.system_name:
 
             is_driver_up_to_date, current_version, latest_version = super()._compare_current_version_and_latest_version_github()
 
@@ -88,7 +84,7 @@ class GeckoDriver(DriverBase):
 
         driver_path = self._download_driver()
 
-        if self.check_driver_is_up_to_date and not self.system_name:
+        if not self.system_name:
 
             is_driver_up_to_date, current_version, latest_version = super()._compare_current_version_and_latest_version_github()
 
@@ -169,9 +165,7 @@ class GeckoDriver(DriverBase):
 
         driver_path : str = ''
 
-        if self.upgrade:
-
-            super()._delete_current_driver_for_current_os()
+        super()._delete_current_driver_for_current_os()
 
         if version:
 
@@ -209,11 +203,7 @@ class GeckoDriver(DriverBase):
             Path(out_path).unlink()
 
         logger.info(f'Started download geckodriver by url: {url}')
-
-        if self.info_messages:
-            archive_path = wget.download(url=url, out=out_path)
-        else:
-            archive_path = wget.download(url=url, out=out_path, bar=None)
+        archive_path = super()._wget_download_driver(url, out_path)
         time.sleep(2)
 
         logger.info(f'Geckodriver was downloaded to path: {archive_path}')
@@ -239,9 +229,7 @@ class GeckoDriver(DriverBase):
 
         logger.info(f'Geckodriver was successfully unpacked by path: {driver_path}')
 
-        if self.chmod:
-
-            super()._chmod_driver()
+        super()._chmod_driver()
 
         return driver_path
         
\ No newline at end of file
