@@ -1,7 +1,5 @@
-#pylint: disable=logging-fstring-interpolation
 #Standart library imports
 import platform
-import re
 
 #Third library imports
 from bs4 import BeautifulSoup
@@ -74,7 +72,7 @@ class SafariDriver(DriverBase):
             if 'safari' in release.text.lower():
                 latest_version = release.text.lower().split('safari ')[1]
 
-                if not '.' in latest_version:
+                if '.' not in latest_version:
                     latest_version = str(float(latest_version))
                 break
 
