@@ -5,6 +5,7 @@ import os
 import stat
 import subprocess
 import re
+import wget
 
 #Local imports
 from selenium_driver_updater._setting import setting
@@ -15,7 +16,6 @@ from selenium_driver_updater.util.github_viewer import GithubViewer
 from selenium_driver_updater.util.logger import logger
 from selenium_driver_updater.util.exceptions import DriverVersionInvalidException
 
-#pylint: disable=logging-fstring-interpolation
 class DriverBase():
     "Base class for all drivers classes in selenium_driver_updater"
 
@@ -33,12 +33,6 @@ class DriverBase():
 
         self.path : str = str(kwargs.get('path'))
 
-        self.upgrade : bool = bool(kwargs.get('upgrade'))
-
-        self.chmod : bool = bool(kwargs.get('chmod'))
-
-        self.check_driver_is_up_to_date : bool = bool(kwargs.get('check_driver_is_up_to_date'))
-
         self.version = str(kwargs.get('version'))
 
         self.info_messages = bool(kwargs.get('info_messages'))
@@ -105,7 +99,7 @@ class DriverBase():
     def _chmod_driver(self) -> None:
         """Tries to give specific driver needed permissions"""
 
-        if Path(self.driver_path).exists():
+        if Path(self.driver_path).exists() and os.name == 'posix':
 
             logger.info(f'Trying to give {self.driver_name} needed permissions')
 
@@ -226,12 +220,27 @@ class DriverBase():
         find_string = re.findall(self.setting["Program"]["wedriverVersionPattern"], url)
         driver_version = find_string[0] if len(find_string) > 0 else ''
 
-        url_test_valid = self.setting[self.driver_name_setting]["LinkCheckVersionIsValid"].format(driver_version)
-        version_valid : str = f"{driver_version}/{archive_name}"
+        if 'chromedriver' in archive_name:
+            url_test_valid = self.setting[self.driver_name_setting]["LinkCheckVersionIsValid"]
+            archive_platform = archive_name.split('-', maxsplit=1)[1].split('.')[0]
+
+            version_valid : str = f"{driver_version}/{archive_platform}/{archive_name}"
+        else:
+            url_test_valid = self.setting[self.driver_name_setting]["LinkCheckVersionIsValid"].format(driver_version)
+            version_valid : str = f"{driver_version}/{archive_name}"
 
         json_data = self.requests_getter.get_result_by_request(url=url_test_valid)
 
-        if not version_valid in json_data:
+        if version_valid not in json_data or not driver_version:
             message = ('Wrong version or system_name was specified.'
                         f'version_valid: {version_valid} driver_version: {driver_version} url: {url}')
             raise DriverVersionInvalidException(message)
+        
+    def _custom_bar(self, current, total, width=80):
+        return wget.bar_adaptive(round(current/1024/1024, 2), round(total/1024/1024, 2), width) + ' MB' + " "
+    
+    def _wget_download_driver(self, url, path):
+        bar = self._custom_bar if self.info_messages else None
+
+        archive_path = wget.download(url=url, out=path, bar=bar)
+        return archive_path
