@@ -2,7 +2,6 @@ from selenium_driver_updater._chromeDriver import ChromeDriver
 from selenium_driver_updater._geckoDriver import GeckoDriver
 from selenium_driver_updater._operaDriver import OperaDriver
 from selenium_driver_updater._edgeDriver import EdgeDriver
-from selenium_driver_updater._phantomJS import PhantomJS
 from selenium_driver_updater._safari_driver import SafariDriver
 
 ALL_DRIVERS= {
@@ -10,6 +9,5 @@ ALL_DRIVERS= {
     "geckodriver" : GeckoDriver,
     "operadriver" : OperaDriver,
     "edgedriver" : EdgeDriver,
-    "phantomjs" : PhantomJS,
     "safaridriver" : SafariDriver,
 }
